pub struct CascadeCycleError {
pub from: Channel,
pub to: Channel,
}Expand description
Error returned when adding a cascade would create a cycle.
Fields
from: ChannelThe source channel of the cascade that would create a cycle.
to: ChannelThe target channel of the cascade that would create a cycle.